@@ -483,7 +483,8 @@ m_CGFunctionEvaluateCallback(void* _info, const CGFloat* inData, CGFloat* outDat
         PyObjCErr_ToObjCWithGILState(&state);
     }
 
-    if (PyObjC_DepythonifyCArray(@encode(CGFloat), rangedim, NO, result, (void*)outData)
+    if (PyObjC_DepythonifyCArray(@encode(CGFloat), rangedim, NO, result, (void*)outData,
+                                 NO, NO)
         < 0) {
         Py_DECREF(result);
         PyObjCErr_ToObjCWithGILState(&state);
@@ -1600,12 +1601,8 @@ static PyMethodDef mod_methods[] = {
     {"CGDataConsumerCreate", (PyCFunction)m_CGDataConsumerCreate, METH_VARARGS,
      doc_CGDataConsumerCreate},
 
-#if PyObjC_BUILD_RELEASE >= 1005
-
     {"CGDataProviderCreateSequential", (PyCFunction)m_CGDataProviderCreateSequential,
      METH_VARARGS, doc_CGDataProviderCreateSequential},
-
-#endif
     {"CGDataProviderCreateWithData", (PyCFunction)m_CGDataProviderCreateWithData,
      METH_VARARGS, doc_CGDataProviderCreateWithData},
 
